@@ -3,6 +3,7 @@ import urllib.parse
 import re
 import unidecode
 import os
+import requests
 
 import flask
 import flask_babel
@@ -190,11 +191,21 @@ def linker():
             pass
         return "Barrin's Codex"
 
+    def page_name():
+        try:
+            if navigation.HELPER.get(path, {}).get("self").path != "":
+                name = navigation.HELPER.get(path, {}).get("self").name
+                return f"{name}"
+        except AttributeError:
+            pass
+        return "Barrin's Codex"
+
     return dict(
         i18n_url=i18n_url,
         link=link,
         translation=translation,
         title=title,
+        page_name=page_name,
         top=top,
         next=next,
         prev=prev,
@@ -274,3 +285,107 @@ def display_card():
         )
 
     return dict(card=card, card_image=card_image, card_art=card_art)
+
+
+@app.context_processor
+def display_deck():
+    def _name(name: str) -> str:
+        name = unidecode.unidecode(name).lower()
+        name = re.sub(r"[^a-zA-Z]", "", name)
+        return name
+
+    def _get(name: str) -> json:
+        qte = re.sub(r"[a-zA-Z]", "", name.split(r" ")[0])
+        info = library[name]
+        return {
+            "count": qte,
+            "name": re.split("/", info["name"])[0],
+            "id": info["id"],
+            "types": info["types"],
+        }
+
+    def deck_from_moxfield(key: str) -> json:
+        url = "https://api.moxfield.com/v2/decks/all/"
+
+        czon = []
+        crea = {"type": "Creatures", "count": 0, "cards": []}
+        plan = {"type": "Planeswalkers", "count": 0, "cards": []}
+        arti = {"type": "Artifacts", "count": 0, "cards": []}
+        ench = {"type": "Enchantments", "count": 0, "cards": []}
+        inst = {"type": "Instants", "count": 0, "cards": []}
+        sorc = {"type": "Sorceries", "count": 0, "cards": []}
+        land = {"type": "Lands", "count": 0, "cards": []}
+
+        deck_json = requests.get(url + key).json()
+
+        for k, v in deck_json["mainboard"].items():
+            name = _name(re.split("/", k)[0])
+            card = _get(name)
+            card["count"] = v["quantity"]
+
+            if "Land" in card["types"]:
+                land["count"] = land["count"] + int(card["count"])
+
+                if len(card["types"]) == 1:
+                    land["cards"].append(card)
+                elif "Creature" in card["types"]:
+                    if "/" not in name:
+                        crea["count"] = crea["count"] + int(card["count"])
+                        land["cards"].append(card)
+                        continue  #: Will never add "Dryad Arbor" to Creatures
+                elif "Enchantment" in card["types"]:
+                    if "/" not in name:
+                        ench["count"] = ench["count"] + int(card["count"])
+                        land["cards"].append(card)
+                        continue  #: Will never add Urza's Saga to Enchantments
+                elif "Artifact" in card["types"]:
+                    if "/" not in name:
+                        arti["count"] = arti["count"] + int(card["count"])
+                        land["cards"].append(card)
+                        continue  #: Will never add Seat of the Synod to Artifacts
+
+            if "Creature" in card["types"]:
+                crea["count"] = crea["count"] + int(card["count"])
+                crea["cards"].append(card)
+
+            elif "Planeswalker" in card["types"]:
+                plan["count"] = plan["count"] + int(card["count"])
+                plan["cards"].append(card)
+
+            elif "Artifact" in card["types"]:
+                arti["count"] = arti["count"] + int(card["count"])
+                arti["cards"].append(card)
+
+            elif "Enchantment" in card["types"]:
+                ench["count"] = ench["count"] + int(card["count"])
+                ench["cards"].append(card)
+
+            elif "Instant" in card["types"]:
+                inst["count"] = inst["count"] + int(card["count"])
+                inst["cards"].append(card)
+
+            elif "Sorcery" in card["types"]:
+                sorc["count"] = sorc["count"] + int(card["count"])
+                sorc["cards"].append(card)
+
+        for k, v in deck_json["commanders"].items():
+            name = _name(re.split("/", k)[0])
+            card = _get(name)
+            card["count"] = v["quantity"]
+            czon.append(card)
+
+        return json.dumps(
+            {
+                "name": deck_json["name"],
+                "date": deck_json["createdAtUtc"][:10],
+                "library": {
+                    "cards": [crea, plan, arti, ench, inst, sorc, land],
+                    "count": (100 - len(czon)),
+                },
+                "command": {"cards": czon, "count": len(czon)},
+            },
+            separators=(",", ":"),
+            sort_keys=True,
+        )
+
+    return dict(decklist=deck_from_moxfield)
