@@ -60,11 +60,11 @@ STRUCTURE = Nav(
                 Nav(lazy_gettext("Aminatou, the Fateshifter")),
                 Nav(lazy_gettext("Arcades, the Strategist")),
                 Nav(lazy_gettext("Doran, the Siege Tower")),
-                Nav(lazy_gettext("Isamaru, Hound of Konda")),
                 Nav(lazy_gettext("Galazeth Prismari")),
                 Nav(lazy_gettext("Golos, Tireless Pilgrim")),
                 Nav(lazy_gettext("Grenzo, Dungeon Warden")),
                 Nav(lazy_gettext("Hogaak, Arisen Necropolis")),
+                Nav(lazy_gettext("Isamaru, Hound of Konda")),
                 Nav(lazy_gettext("Kelsien, the Plague")),
                 Nav(lazy_gettext("Kess, Dissident Mage")),
                 Nav(lazy_gettext("Kinnan, Bonder Prodigy")),
@@ -79,23 +79,21 @@ STRUCTURE = Nav(
                 Nav(lazy_gettext("The Omenkeel")),
                 Nav(lazy_gettext("Titania, Protector of Argoth")),
                 Nav(lazy_gettext("Venser, Shaper Savant")),
-                Nav(lazy_gettext("Winota, Joiner of Forces")),
+                Nav(
+                    lazy_gettext("Decks bannis"),
+                    index=True,
+                    children=[
+                        Nav(lazy_gettext("Asmoranomardicadaistinaculdacar")),
+                        Nav(lazy_gettext("Winota, Joiner of Forces")),
+                    ],
+                ),
             ],
         ),
         Nav(
             lazy_gettext("Articles"),
             index=True,
             children=[
-                Nav(
-                    lazy_gettext("Classifier un deck"),
-                    index=True,
-                    children=[
-                        Nav(lazy_gettext("Les macrotypes")),
-                        Nav(lazy_gettext("Les archétypes")),
-                        Nav(lazy_gettext("Les tiers")),
-                        Nav(lazy_gettext("Pour aller plus loin")),
-                    ],
-                ),
+                Nav(lazy_gettext("Classifier un deck")),
                 Nav(lazy_gettext("Construire un deck")),
             ],
         ),
@@ -124,9 +122,9 @@ STRUCTURE = Nav(
                         Nav(lazy_gettext("Les Grosses Créatures")),
                     ],
                 ),
-                Nav(lazy_gettext("Les Piocheurs")),
                 Nav(lazy_gettext("Les Spot Removals")),
                 Nav(lazy_gettext("Les Mass Removals")),
+                Nav(lazy_gettext("Les Piocheurs")),
             ],
         ),
         Nav(
